# Clean Sinhala Words

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)
[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)

- Make sure you have Python installed in your system.
- Run Following command in the CMD.
 ```
  pip install CleanSinhala
  ```

 ```
  from CleanSinhala import simplify
  ```
 
# Convert Sinhala wrong spell words to meaningfull words 

##Egsample

```
  from Clean_Words import simplify
  print(simplify('Chanaka'))
  ```
 returens
 ```
 Chanaka
 ```